<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Http\Request;

class UsersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = User::whereType('user')->orderByDesc('id')->get();
        return view('admin.users.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.users.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users',
            'mobile' => 'required|unique:users',
            'password' => 'required|min:6',
            'status' => 'required|in:active,not_active'
        ]);
        $user = new User();
        $user['name'] = $request['name'];
        $user['email'] = $request['email'];
        $user['mobile'] = $request['mobile'];
        $user['status'] = $request['status'];
        $user['password'] = bcrypt($request['password']);
        $user['type'] = 'user';
        $user->save();
        return redirect()->route('users.index')->with('message', 'تم الانشاء بنجاح');


    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = User::find($id);
        return view('admin.users.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,' . $id,
            'mobile' => 'required|unique:users,mobile,' . $id,
            'password' => 'nullable|min:6',
            'status' => 'required|in:active,not_active'
        ]);
        $user = User::find($id);
        $user['name'] = $request['name'];
        $user['email'] = $request['email'];
        $user['status'] = $request['status'];
        if ($request['password']) $user['password'] = bcrypt($request['password']);

        $user['type'] = 'user';
        $user['mobile'] = $request['mobile'];
        $user->update();
        return redirect()->route('users.index')->with('message', 'تم التعديل بنجاح');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        User::destroy($id);
        return redirect()->back()->with('message', 'تم الحذف بنجاح');
    }
}
