<?php

namespace App\Http\Controllers\web;

use App\Http\Controllers\Controller;
use App\Http\Resources\CommentsResource;
use App\Models\AdditionalType;
use App\Models\Category;
use App\Models\City;
use App\Models\Comment;
use App\Models\Notification;
use App\Models\Product;
use App\Models\ProductImage;
use App\Models\Spam;
use App\Models\UserToken;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;

class ProductsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
    }

    public function car_option_rules()
    {
        return [
            'title' => 'required',
            'category_id' => 'required|exists:categories,id',
            'city_id' => 'required|exists:cities,id',
            'county_id' => 'required_if:city_id,null|exists:cities,id',
            'hide_mobile' => 'in:true,false',
            'mobile' => 'required_if:hide_mobile,false',
            'ad_type' => 'required|in:buy,waiver',
            'year' => 'required',
            'car_status' => 'required|in:used,new,accident',
            'fetis' => 'required|in:manual,automatic',
            'fuel' => 'required|in:gasoline,hybrid,diesel',
            'double' => 'required|in:true,false',
            'km' => 'required',
            'detail' => 'required',
            'lat' => 'nullable',
            'lng' => 'nullable',
            'installment_destination' => 'nullable',
            'determine_price' => 'required|in:true,false',
            'price' => 'required_if:determine_price,true',
            'swear' => 'accepted',
            'images' => 'required'


        ];
    }

    public function rules()
    {
        return [
            'title' => 'required',
            'category_id' => 'required|exists:categories,id',
            'city_id' => 'required|exists:cities,id',
            'county_id' => 'required_if:city_id,null|exists:cities,id',
            'hide_mobile' => 'in:true,false',
            'mobile' => 'required_if:hide_mobile,false',
            'ad_type' => 'nullable|in:buy,waiver',
            'year' => 'nullable',
            'car_status' => 'nullable|in:used,new,accident',
            'fetis' => 'nullable|in:manual,automatic',
            'fuel' => 'nullable|in:gasoline,hybrid,diesel',
            'double' => 'nullable|in:true,false',
            'km' => 'nullable',
            'detail' => 'required',
            'lat' => 'nullable',
            'lng' => 'nullable',
            'installment_destination' => 'nullable',
            'determine_price' => 'required|in:true,false',
            'price' => 'required_if:determine_price,true',
            'swear' => 'accepted',
            'images' => 'required'


        ];
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if (!\Auth::check()) return redirect()->route('home')->with('error', \Lang::get('data.login_first'));

        $ad_types = AdditionalType::all();
        $cities = City::where('type', 'city')->get();
        $categories = Category::where('parent_id', null)->get();
        return view('web.products.create', compact('ad_types', 'cities', 'categories'));

    }

    public function grand_categories_ajax(Request $request)
    {
        $ad_type = AdditionalType::find($request->ad_type); // Ad type from request

        $categories = Category::whereParentId(null)->get(); // all grand without parent id


        $single_category = Category::find($ad_type->category_id); // exact category

        if ($single_category->car_option == 'true') {
            $car_option = 'true';
        } else {
            $car_option = 'false';
        }

        $parent_categories = Category::whereParentId($single_category->id)->get();
        $grand_view = view('web.products.grand_category_foreach', compact('ad_type', 'categories', 'single_category'))->render();
        $parent_view = view('web.products.parent_category_foreach', compact('parent_categories'))->render();
        return response()->json(['value' => true, 'grand_view' => $grand_view, 'parent_view' => $parent_view, 'car_option' => $car_option]);
    }

    public function get_categories_ajax(Request $request)
    {
        $selected_category = Category::find($request->category_id);
        if ($selected_category->car_option == 'true') {
            $car_option = 'true';
        } else {
            $car_option = 'false';
        }
        $child_categories = Category::whereParentId($request->category_id)->get();
        $child_view = view('web.products.categories_foreach', compact('child_categories'))->render();
        return response()->json(['value' => true, 'child_view' => $child_view, 'car_option' => $car_option]);
    }

    public function get_parent_categories_ajax(Request $request)
    {
        $selected_category = Category::find($request->category_id);
        if ($selected_category->car_option == 'true') {
            $car_option = 'true';
        } else {
            $car_option = 'false';
        }
        $parent_categories = Category::whereParentId($request->category_id)->get();
        $parent_view = view('web.products.parent_category_foreach', compact('parent_categories'))->render();
        return response()->json(['value' => true, 'parent_view' => $parent_view, 'car_option' => $car_option]);
    }

    public function get_cities_ajax(Request $request)
    {
        $cities = City::whereParentId($request->city_id)->get();
        $cities_view = view('web.products.cities_foreach', compact('cities'))->render();
        return response()->json(['value' => true, 'cities_view' => $cities_view]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if (!\Auth::check()) return redirect()->back()->with('error', \Lang::get('data.login_first'));
        $grand_id = $request['grand_id'];
        $parent_id = $request['parent_id'];
        $category_id = $request['category_id'];


        // grand
        // parent
        // category is child
        if ($grand_id != null && $parent_id == null && $category_id == null) {

            $final_category_id = $grand_id;

        }elseif ($grand_id != null && $parent_id != null && $category_id == null){
            $final_category_id = $parent_id;
        }elseif ($grand_id !=null && $parent_id !=null && $category_id !=null){
            $final_category_id = $category_id;
        }else{
            return redirect()->back()->with('error', \Lang::get('data.category_missed'));

        }


        $category = Category::find($final_category_id);
        if ($category->car_option == 'true') {

            $this->validate($request, $this->car_option_rules());
        } else {

            $this->validate($request, $this->rules());
        }

        $user = \Auth::user();
        $product = new Product();
        $product['user_id'] = $user->id;
        $product['title'] = $request['title'];
        $product['category_id'] = $category->id;
        $product['city_id'] = $request['county_id'] ? $request['county_id'] : $request['city_id'];
        $product['mobile'] = $request['mobile'];
        $product['hide_mobile'] = $request['hide_mobile'];
        $product['ad_type'] = $request['ad_type'];
        $product['year'] = $request['year'];
        $product['car_status'] = $request['car_status'];
        $product['installment_destination'] = $request['installment_destination'];
        $product['fetis'] = $request['fetis'];
        $product['fuel'] = $request['fuel'];
        $product['double'] = $request['double'];
        $product['km'] = $request['km'];
        $product['determine_price'] = $request['determine_price'];
        $product['price'] = $request['price'];
        $product['detail'] = $request['detail'];
        $product['lat'] = $request['lat'];
        $product['lng'] = $request['lng'];
        $product['views'] = 0;
        $product['status'] = 'active';
        $product['code'] = uniqid();
        $product->save();

        if ($request->images) {
            $image_array = $request['images'];
            $i = 1;
            foreach ($image_array as $image) {
                $filename = time() . $i . '.' . $image->getClientOriginalExtension();
                $image->move(public_path('images/products'), $filename);
                ProductImage::create([
                    'product_id' => $product->id,
                    'image' => $filename
                ]);
                $i++;
            }
        }

        if (count($product->images) == 0) {

            $notification = new Notification();
            $notification['user_id'] = $user->id;
            $notification['body->ar'] = 'عميلنا العزيز اضافه صوره لأعلانكم يزيد من نسبه التفاعل ';
            $notification['body->en'] = 'Our dear customer, adding a picture to your advertisement increases the rate of interaction';
            $notification['title->en'] = 'Add Images';
            $notification['product_id'] = $product->id;
            $notification['title->ar'] = 'إضافة صور';
            $notification['type'] = 'admin';
            $notification->save();

            $all_tokens = UserToken::whereStatus('connected')->whereUserId($user->id)->get();
            $push = new PushNotification('fcm');

            foreach ($all_tokens as $token) {

                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification->title['ar'],
                            'title_en' => $notification->title['en'],
                            'body_ar' => $notification->body['ar'],
                            'body_en' => $notification->body['en'],
                            'type' => $notification->type,
                            'product_id' => $product->id,
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $notification->title['ar'],
                            'title_en' => $notification->title['en'],
                            'body_ar' => $notification->body['ar'],
                            'body_en' => $notification->body['en'],
                            'type' => $notification->type,
                            'product_id' => $product->id,

                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification->title['ar'],
                            'title_en' => $notification->title['en'],
                            'body_ar' => $notification->body['ar'],
                            'body_en' => $notification->body['en'],
                            'type' => $notification->type,
                            'product_id' => $product->id,

                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token)
                        ->send();

                }


            }


        }


        $user_name = $user->name ? $user->name : $user->mobile;
        $followers = $user->followers->pluck('id');
        $followers_tokens = UserToken::whereIn('user_id', $followers)->whereStatus('connected')->get();
        $push = new PushNotification('fcm');

        foreach ($followers_tokens as $token) {

            if ($token->device_type == 'ios') {
                $msg = [
                    'data' => [
                        'title_ar' => " قام  $user_name بإنشاء إعلان جديد  ",
                        'title_en' => "Your Following $user_name posted a new product",
                        'body_ar' => " قام  $user_name بإنشاء إعلان جديد  ",
                        'body_en' => "Your Following $user_name posted a new product",
                        'type' => "follower",
                        'product_id' => $product->id,
                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'notification' => [
                        'title_ar' => " قام  $user_name بإنشاء إعلان جديد  ",
                        'title_en' => "Your Following $user_name posted a new product",
                        'body_ar' => " قام  $user_name بإنشاء إعلان جديد  ",
                        'body_en' => "Your Following $user_name posted a new product",
                        'type' => "follower",
                        'product_id' => $product->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token)
                    ->send();

            } else {
                $msg = [
                    'data' => [
                        'title_ar' => " قام  $user_name بإنشاء إعلان جديد  ",
                        'title_en' => "Your Following $user_name posted a new product",
                        'body_ar' => " قام  $user_name بإنشاء إعلان جديد  ",
                        'body_en' => "Your Following $user_name posted a new product",
                        'type' => "follower",
                        'product_id' => $product->id,

                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token)
                    ->send();

            }

            $notification = new Notification();
            $notification['user_id'] = $token->user_id;
            $notification['body->ar'] = " قام  $user_name بإنشاء إعلان جديد  ";
            $notification['body->en'] = "Your Following $user_name posted a new product";
            $notification['title->en'] = "Your Following $user_name posted a new product";
            $notification['product_id'] = $product->id;
            $notification['title->ar'] = " قام  $user_name بإنشاء إعلان جديد  ";
            $notification['type'] = 'follower';
            $notification->save();

        }


        return redirect()->route('product.show', $product->code)->with('message', \Lang::get('data.product_added'));


    }

    /**
     * Display the specified resource.
     *
     * @param int $code
     * @return \Illuminate\Http\Response
     */
    public function show($code)
    {
        $row = Product::whereCode($code)->first();

        $similar_products = Product::where('category_id', $row->category->id)->where('id', '!=', $row->id)->take(6)->orderByDesc('id')->get();
        return view('web.products.show', compact('row', 'similar_products'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function add_comment_web(Request $request)
    {
        if ($request->comment) {
            $row = new Comment();
            $row->product_id = $request->product_id;
            $row->user_id = \Auth::user()->id;
            $row->body = $request->comment;
            $row->save();
            return response()->json(['value' => true, 'msg' => \Lang::get('data.add_comment'), 'data' => new CommentsResource($row)]);
        }
        return response()->json(['value' => false, 'msg' => \Lang::get('data.error_comment'), 'data' => []]);

    }

    public function spam_web(Request $request)
    {
        $spam = Spam::where(['user_id' => \Auth::user()->id, 'product_id' => $request->product_id, 'type' => $request->type, 'comment_id' => $request->comment_id])->first();
        if (!$spam) {
            $row = new Spam();
            $row->user_id = \Auth::user()->id;
            $row->product_id = $request->product_id;
            $row->type = $request->type;
            if ($request->type == 'comment') {
                $row->comment_id = $request->comment_id;
            }
            $row->save();
            return response()->json(['msg' => \Lang::get('data.spam_web')]);
        }
    }
}
