<?php

namespace App\Http\Controllers\Web;

use App\Http\Controllers\Controller;
use App\Mail\ResetCode;
use App\Models\Banner;
use App\Models\Category;
use App\Models\Product;
use App\Models\Setting;
use App\User;
use Illuminate\Http\Request;

class HomeController extends Controller
{
    public function index()
    {
        $cat_id = Setting::first() != null ? Setting::first()->value('category_id') : 0;
        $banners = Banner::whereShowHome('true')->inRandomOrder()->paginate(3);
        $home_categories = Category::where(['status' => 'active', 'parent_id' => $cat_id])->get();
        $taps_categories = Category::whereParentId(null)->get();
        $rows = Product::inRandomOrder()->paginate(12);
        return view('web.index', compact('banners', 'taps_categories', 'rows', 'home_categories'));
    }


    public function user_login(Request $request)
    {
        $this->validate($request, [
            'email' => 'required|email',
            'password' => 'required'
        ]);
        if (\Auth::attempt(['email' => $request['email'], 'password' => $request['password'], 'status' => 'active', 'type' => 'user'])) {
            $user = User::whereEmail($request->email)->first();
            $user->online = 'true';
            $user->update();
            return redirect()->back()->with('message', \Lang::get('data.welcome'));
        } else {
            return redirect()->back()->with('error', \Lang::get('data.error_login_credentials'));
        }
    }

    public function user_register(Request $request)
    {
        $this->validate($request, [
            'mobile' => 'required|unique:users,mobile',
            'email' => 'email|required|unique:users,email',
            'city_id' => 'required|exists:cities,id',
            'password' => 'required|confirmed',
            'password_confirmation' => 'required'
        ]);
        $user = User::create([
            'mobile' => $request['mobile'],
            'city_id' => $request['city_id'],
            'password' => bcrypt($request['password']),
            'online' => 'true',
            'email'=>$request['email']
        ]);
        \Auth::login($user);
        return redirect()->back()->with('message', \Lang::get('data.welcome'));
    }

    public function logout()
    {
        \Auth::user()->update([
            'online' => 'false'
        ]);
        \Auth::logout();

        return redirect()->route('home')->with('message', \Lang::get('data.logout'));
    }

    public function update_forget_password(Request $request)
    {
        $user = User::whereEmail($request->email)->first();


        $code = rand(1111, 9999);
        $user->code = $code;
        $user->update();
        // email code

        \Mail::to($user->email)->send(new ResetCode($code));

        \Session::put('mobile', $user->mobile);
        \Session::put('country_code', $request['country_code']);
        return response()->json(['status' => 1, 'code_sent' => \Lang::get('data.code_sent')]);


    }

    public function forget_password(Request $request)
    {
        $this->validate($request, [
            'email' => 'email|required',
        ]);


        $user = User::whereEmail($request['email'])->first();


        if ($user) {
            $code = rand(1111, 9999);
            $user->code = $code;
            $user->update();
            // sms code
            \Mail::to($request['email'])->send(new ResetCode($code));
            \Session::put('email', $user->email);
            \Session::put('country_code', $request['country_code']);
            return redirect()->route('forget_password_user');

        } else {
            return redirect()->back()->with('error', \Lang::get('data.mobile_not_found'));
        }

    }

    public function user_rest_password(Request $request)
    {
        $this->validate($request, [
            'code' => 'required'
        ]);

        $code = implode("", $request['code']);
        $email = \Session::get('email');
        $user = User::whereEmail($email)->first();
        if ($user->code == $code) {
            \Session::put('user_id', $user->id);
            return view('web.reset_password');
        } else {
            return back()->with('error', \Lang::get('data.error_code'));
        }
    }

    public function forget_password_user()
    {
        return view('web.forget_code');
    }

    public function update_password(Request $request)
    {
        $this->validate($request, [
            'password' => 'required|confirmed',
            'password_confirmation' => 'required'
        ]);
        $user_id = \Session::get('user_id');
        $user = User::find($user_id);
        $user->password = bcrypt($request['password']);
        $user->update();
        \Auth::login($user);
        return redirect()->route('home')->with('message', \Lang::get('data.welcome'));
    }

    public function special_ads()
    {
        return view('web.data.special_ads');
    }

}
