<?php

namespace App\Models;

use App\User;
use JWTAuth;
use Tymon\JWTAuth\Exceptions\JWTException;
use Illuminate\Database\Eloquent\Model;

class Product extends Model
{
    protected $table = 'products';
    protected $fillable = ['title', 'category_id', 'city_id', 'mobile', 'hide_mobile', 'ad_type', 'year', 'car_status', 'installment_destination', 'fetis', 'fuel', 'double', 'km', 'determine_price', 'price', 'detail'
        , 'lat', 'lng', 'views', 'status', 'user_id', 'code', 'stop_comments'
    ];
    protected $appends = ['is_favorite'];


    public function getIsFavoriteAttribute()
    {
        if (request()->header('Authorization')) {

            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return false;
            } else {

                $fav = Favourite::where(['user_id' => $user->id, 'product_id' => $this->id])->first();
                if ($fav) {
                    return true;
                } else {
                    return false;
                }
            }
        }

    }

    public function deleteImage()
    {
        foreach ($this->images as $image) {
            @unlink(public_path('images/products/' . $image->attributes['image']));
        }
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function category()
    {
        return $this->belongsTo(Category::class, 'category_id');
    }

    public function city()
    {
        return $this->belongsTo(City::class, 'city_id');
    }


    public function users()
    {
        return $this->belongsToMany(User::class, 'favourites', 'product_id', 'user_id');
    }

    public function notifications()
    {
        return $this->hasMany(Notification::class, 'product_id');
    }

    public function images()
    {
        return $this->hasMany(ProductImage::class, 'product_id');
    }

    public function spams()
    {
        return $this->hasMany(Spam::class, 'product_id');
    }

    public function comments()
    {
        return $this->hasMany(Comment::class, 'product_id');
    }

    public function user_views()
    {
        return $this->belongsToMany(User::class, 'views', 'product_id', 'user_id');
    }
}
